[coreboot] [commit] r5649 - in trunk/src/superio/smsc: lpc47m10x lpc47m15x

repository service svn at coreboot.org
Tue Jun 29 23:02:32 CEST 2010


Author: stepan
Date: Tue Jun 29 23:02:32 2010
New Revision: 5649
URL: https://tracker.coreboot.org/trac/coreboot/changeset/5649

Log:
fix misnamed functions.
Signed-off-by: Stefan Reinauer <stepan at coresystems.de>
Acked-by: Stefan Reinauer <stepan at coresystems.de>

Modified:
   trunk/src/superio/smsc/lpc47m10x/lpc47m10x_early_serial.c
   trunk/src/superio/smsc/lpc47m15x/lpc47m15x_early_serial.c

Modified: trunk/src/superio/smsc/lpc47m10x/lpc47m10x_early_serial.c
==============================================================================
--- trunk/src/superio/smsc/lpc47m15x/lpc47m15x_early_serial.c	Mon Jun 28 12:40:38 2010	(r5648)
+++ trunk/src/superio/smsc/lpc47m15x/lpc47m15x_early_serial.c	Tue Jun 29 23:02:32 2010	(r5649)
@@ -34,7 +34,7 @@
 	outb(0xaa, port);
 }
 
-static inline void lpc47b272_enable_serial(device_t dev, unsigned iobase)
+static inline void lpc47m15x_enable_serial(device_t dev, unsigned iobase)
 {
 	pnp_enter_conf_state(dev);
 	pnp_set_logical_device(dev);




More information about the coreboot mailing list
--- trunk/src/superio/smsc/lpc47m10x/lpc47m10x_early_serial.c	Mon Jun 28 12:40:38 2010	(r5648)
+++ trunk/src/superio/smsc/lpc47m10x/lpc47m10x_early_serial.c	Tue Jun 29 23:02:32 2010	(r5649)
@@ -47,15 +47,15 @@
 }
 
 /*
- * Function:    	lpc47b272_enable_serial
+ * Function:    	lpc47m10x_enable_serial
  * Parameters:  	dev - high 8 bits = Super I/O port,
  *			      low 8 bits = logical device number (per lpc47b272.h)
  *			iobase - processor I/O port address to assign to this serial device
  * Return Value:	bool
  * Description: 	Configure the base I/O port of the specified serial device
  *			and enable the serial device.
  */
-static void lpc47b272_enable_serial(device_t dev, unsigned iobase)
+static void lpc47m10x_enable_serial(device_t dev, unsigned iobase)
 {
 	pnp_enter_conf_state(dev);
 	pnp_set_logical_device(dev);
@@ -47,15 +47,15 @@
  * Parameters:  	dev - high 8 bits = Super I/O port,
- *			      low 8 bits = logical device number (per lpc47b272.h)
+ *			      low 8 bits = logical device number (per lpc47m10x.h)
  *			iobase - processor I/O port address to assign to this serial device
  * Return Value:	bool

Modified: trunk/src/superio/smsc/lpc47m15x/lpc47m15x_early_serial.c
==============================================================================